==> enterprisemodules-easy_type-2.40.0.tar.gz: enterprisemodules-easy_type-2.40.0/lib/puppet/type/fact_group.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

require 'easy_type'
require 'hocon/parser/config_document_factory'
require 'hocon/config_value_factory'

# TODO: Add documentation
Puppet::Type.newtype(:fact_group) do
  include EasyType

  def self.module_name
    'easy_type'
  end

  desc <<-DESC
  Manage the available fact groups.

  Here is an example on how you can create a fact group:

        fact_group {'my_group':
          ensure => 'present',
          facts  => ['my_fact_1','my_fact_2']
        }

  See [here](https://puppet.com/docs/puppet/7/configuring_facter.html#configuring_facter-facter-conf-fact-groups) for more details about fact groups.

  DESC

  def self.config_dir
    kernel = Facter.value(:kernel)
    case kernel
    when 'Linux'
      '/etc/puppetlabs/facter'
    when 'windows'
      'C:/ProgramData/PuppetLabs/facter/etc'      
    else
      fail "'#{kernel}' not (yet) supported."
    end
  end

  def self.config_file
    "#{config_dir}/facter.conf"
  end

  def self.config_data
    @config_data ||= Hocon::ConfigFactory.parse_file(config_file).resolve
  end

  def config_doc
    @config_doc ||= if File.exist?(self.class.config_file)
                      Hocon::Parser::ConfigDocumentFactory.parse_file(self.class.config_file)
                    else
                      Hocon::Parser::ConfigDocumentFactory.parse_string('')
                    end
  end

  def current_config
    @current_config ||= Hocon.load(self.class.config_file)['fact-groups']
  end

  def write_config
    @config_doc = config_doc.set_config_value('fact-groups',
                                              Hocon::ConfigValueFactory.from_any_ref(@new_value))
    FileUtils.mkdir_p(self.class.config_dir) unless File.exists?(self.class.config_dir) 
    File.write(self.class.config_file, config_doc.render)
  end

  to_get_raw_resources do
    groups = if config_data.has_path?('fact-groups')
               data = config_data.get_value('fact-groups').unwrapped
               data.collect { |k, v| { :name => k, :facts => v } }
             else
               []
             end
  end

  def current_value
    current_config || {}
  end

  on_create do
    @new_value = current_value.merge({ name => facts })
    write_config
  end

  on_destroy do
    @new_value = current_value.tap { |hsh| hsh.delete(name) }
    write_config
  end

  on_modify do
    @new_value = current_value
    @new_value[name] = facts
    nil
  end

  after_modify do
    write_config
  end

  ensurable

  parameter :name
  property  :facts
end

==> enterprisemodules-easy_type-2.46.6.tar.gz: enterprisemodules-easy_type-2.46.6/lib/puppet/type/fact_group.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

require 'easy_type'
require 'hocon/parser/config_document_factory'
require 'hocon/config_value_factory'

# TODO: Add documentation
Puppet::Type.newtype(:fact_group) do
  include EasyType

  def self.module_name
    'easy_type'
  end

  desc <<-DESC
  Manage the available fact groups.

  Here is an example on how you can create a fact group:

        fact_group {'my_group':
          ensure => 'present',
          facts  => ['my_fact_1','my_fact_2']
        }

  See [here](https://puppet.com/docs/puppet/7/configuring_facter.html#configuring_facter-facter-conf-fact-groups) for more details about fact groups.

  DESC

  def self.config_dir
    kernel = Facter.value(:kernel)
    case kernel
    when 'Linux'
      '/etc/puppetlabs/facter'
    when 'windows'
      'C:/ProgramData/PuppetLabs/facter/etc'      
    else
      fail "'#{kernel}' not (yet) supported."
    end
  end

  def self.config_file
    "#{config_dir}/facter.conf"
  end

  def self.config_data
    @config_data ||= Hocon::ConfigFactory.parse_file(config_file).resolve
  end

  def config_doc
    @config_doc ||= if File.exist?(self.class.config_file)
                      Hocon::Parser::ConfigDocumentFactory.parse_file(self.class.config_file)
                    else
                      Hocon::Parser::ConfigDocumentFactory.parse_string('')
                    end
  end

  def current_config
    @current_config ||= Hocon.load(self.class.config_file)['fact-groups']
  end

  def write_config
    @config_doc = config_doc.set_config_value('fact-groups',
                                              Hocon::ConfigValueFactory.from_any_ref(@new_value))
    FileUtils.mkdir_p(self.class.config_dir) unless File.exist?(self.class.config_dir) 
    File.write(self.class.config_file, config_doc.render)
  end

  to_get_raw_resources do
    groups = if config_data.has_path?('fact-groups')
               data = config_data.get_value('fact-groups').unwrapped
               data.collect { |k, v| { :name => k, :facts => v } }
             else
               []
             end
  end

  def current_value
    current_config || {}
  end

  on_create do
    @new_value = current_value.merge({ name => facts })
    write_config
  end

  on_destroy do
    @new_value = current_value.tap { |hsh| hsh.delete(name) }
    write_config
  end

  on_modify do
    @new_value = current_value
    @new_value[name] = facts
    nil
  end

  after_modify do
    write_config
  end

  ensurable

  parameter :name
  property  :facts
end
